@@ -1,5 +1,6 @@
 import argparse
 import logging
+import os
 import shutil
 import tempfile
 
@@ -9,14 +10,14 @@ from . import validation
 from . import ui
 
 
-def start_ui():
+def start_ui(logging_level):
     """ Open the interface """
+    # Suppress the global logger to only show error+ to the console
+    logging.getLogger().handlers[0].setLevel(logging_level)
+
     # Setup a temporary folder to build in
     config.temporary_directory = tempfile.mkdtemp()
 
-    # Suppress the global logger to only show error+ to the console
-    logging.getLogger().handlers[0].setLevel(logging.ERROR)
-
     # Start UI
     ui.start(not config.disable_chrome)
 
@@ -49,6 +50,21 @@ def run():
         help="a json file containing a UI configuration",
         default=None
     )
+    parser.add_argument(
+        "-o",
+        "--output-dir",
+        nargs='?',
+        help="the directory to put output in",
+        default='output'
+    )
+    parser.add_argument(
+        "--logging-level",
+        nargs='?',
+        type=validation.argparse_logging_level,
+        choices=['DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL'],
+        help="the level to use for logging - defaults to ERROR",
+        default='ERROR'
+    )
     parser.add_argument(
         "--version",
         action="store_true",
@@ -60,12 +76,14 @@ def run():
     config.package_filename = args.filename
     config.disable_chrome = args.no_chrome
     config.supplied_ui_configuration = args.config
+    config.default_output_directory = os.path.abspath(args.output_dir)
 
     # If the user has asked for the version, print it, otherwise run the application
     if args.version:
         print('auto-py-to-exe ' + __version__)
     else:
-        start_ui()
+        logging_level = getattr(logging, args.logging_level)
+        start_ui(logging_level)
 
 
 if __name__ == '__main__':
